@@ -1,6 +1,5 @@
 """Read and write Jupyter notebooks as text files"""
 
-import io
 import logging
 import os
 import sys
@@ -109,6 +108,7 @@ class TextNotebookConverter(NotebookReader, NotebookWriter):
         metadata, jupyter_md, header_cell, pos = header_to_metadata_and_cell(
             lines,
             self.implementation.header_prefix,
+            self.implementation.header_suffix,
             self.implementation.extension,
             self.fmt.get(
                 "root_level_metadata_as_raw_cell",
@@ -395,6 +395,9 @@ def read(fp, as_version=nbformat.NO_CONVERT, fmt=None, config=None, **kwargs):
 
     if fp == "-":
         text = sys.stdin.read()
+        # Update the input format by reference if missing
+        if isinstance(fmt, dict) and not fmt:
+            fmt.update(long_form_one_format(divine_format(text)))
         return reads(text, fmt)
 
     if not hasattr(fp, "read"):
@@ -405,7 +408,7 @@ def read(fp, as_version=nbformat.NO_CONVERT, fmt=None, config=None, **kwargs):
         if not isinstance(fmt, dict):
             fmt = long_form_one_format(fmt)
         fmt.update({"extension": ext})
-        with io.open(fp, encoding="utf-8") as stream:
+        with open(fp, encoding="utf-8") as stream:
             return read(stream, as_version=as_version, fmt=fmt, config=config, **kwargs)
 
     if fmt is not None:
@@ -454,20 +457,9 @@ def writes(notebook, fmt, version=nbformat.NO_CONVERT, config=None, **kwargs):
     ext = fmt["extension"]
     format_name = fmt.get("format_name")
 
-    jupytext_metadata = metadata.get("jupytext", {})
-
     if ext == ".ipynb":
-        # Remove jupytext section if empty
-        jupytext_metadata.pop("text_representation", {})
-        if not jupytext_metadata:
-            metadata.pop("jupytext", {})
         return nbformat.writes(
-            NotebookNode(
-                nbformat=notebook.nbformat,
-                nbformat_minor=notebook.nbformat_minor,
-                metadata=metadata,
-                cells=notebook.cells,
-            ),
+            drop_text_representation_metadata(notebook, metadata),
             version,
             **kwargs,
         )
@@ -483,6 +475,27 @@ def writes(notebook, fmt, version=nbformat.NO_CONVERT, config=None, **kwargs):
     return writer.writes(notebook, metadata)
 
 
+def drop_text_representation_metadata(notebook, metadata=None):
+    """When the notebook is saved to an ipynb file, we drop the text_representation metadata"""
+    if metadata is None:
+        # Make a copy to avoid modification by reference
+        metadata = deepcopy(notebook["metadata"])
+
+    jupytext_metadata = metadata.get("jupytext", {})
+    jupytext_metadata.pop("text_representation", {})
+
+    # Remove the jupytext section if empty
+    if not jupytext_metadata:
+        metadata.pop("jupytext", {})
+
+    return NotebookNode(
+        nbformat=notebook["nbformat"],
+        nbformat_minor=notebook["nbformat_minor"],
+        metadata=metadata,
+        cells=notebook["cells"],
+    )
+
+
 def write(nb, fp, version=nbformat.NO_CONVERT, fmt=None, config=None, **kwargs):
     """Write a notebook to a file name or a file object
 
@@ -511,7 +524,7 @@ def write(nb, fp, version=nbformat.NO_CONVERT, fmt=None, config=None, **kwargs):
         fmt = long_form_one_format(fmt, update={"extension": ext})
         create_prefix_dir(fp, fmt)
 
-        with io.open(fp, "w", encoding="utf-8") as stream:
+        with open(fp, "w", encoding="utf-8") as stream:
             write(nb, stream, version=version, fmt=fmt, config=config, **kwargs)
             return
     else:
