@@ -26,6 +26,9 @@ _JUPYTER_LANGUAGES = [
     "spark",
     "sql",
     "cython",
+    "haskell",
+    "tcl",
+    "gnuplot",
 ]
 
 # Supported file extensions (and languages)
@@ -63,6 +66,14 @@ _SCRIPT_EXTENSIONS = {
         "comment": "(*",
         "comment_suffix": "*)",
     },  # OCaml only has block comments
+    ".hs": {"language": "haskell", "comment": "--"},
+    ".tcl": {"language": "tcl", "comment": "#"},
+    ".mac": {
+        "language": "maxima",
+        "comment": "/*",
+        "comment_suffix": "*/",
+    },  # Maxima only has block comments
+    ".gp": {"language": "gnuplot", "comment": "#"},
 }
 
 _COMMENT_CHARS = [
@@ -165,11 +176,10 @@ def set_main_and_cell_language(metadata, cells, ext, custom_cell_magics):
                 if "magic_args" in cell["metadata"]:
                     magic_args = cell["metadata"].pop("magic_args")
                     cell["source"] = (
-                        u"{}{} {}\n".format(magic, language, magic_args)
-                        + cell["source"]
+                        f"{magic}{language} {magic_args}\n" + cell["source"]
                     )
                 else:
-                    cell["source"] = u"{}{}\n".format(magic, language) + cell["source"]
+                    cell["source"] = f"{magic}{language}\n" + cell["source"]
 
 
 def cell_language(source, default_language, custom_cell_magics):
