@@ -1,12 +1,9 @@
-# -*- coding: utf-8 -*-
-
 import os
 import sys
 import time
 import unittest.mock as mock
 import warnings
 from argparse import ArgumentTypeError
-from contextlib import contextmanager
 from io import StringIO
 from shutil import copyfile
 from subprocess import check_call
@@ -67,6 +64,7 @@ def test_convert_single_file_in_place(nb_file, tmpdir):
     compare_notebooks(nb2, nb1)
 
 
+@requires_jupytext_installed
 def test_convert_single_file_in_place_m(tmpdir):
     nb_file = list_notebooks("ipynb_py")[0]
     nb_org = str(tmpdir.join(os.path.basename(nb_file)))
@@ -438,6 +436,7 @@ def test_update_metadata(py_file, tmpdir, capsys):
     assert "invalid" in err
 
 
+@requires_user_kernel_python3
 @pytest.mark.parametrize("py_file", list_notebooks("python"))
 def test_set_kernel_inplace(py_file, tmpdir):
     tmp_py = str(tmpdir.join("notebook.py"))
@@ -452,6 +451,7 @@ def test_set_kernel_inplace(py_file, tmpdir):
     assert cmd == "python" or os.path.samefile(cmd, sys.executable)
 
 
+@requires_user_kernel_python3
 @pytest.mark.parametrize("py_file", list_notebooks("python"))
 def test_set_kernel_auto(py_file, tmpdir):
     tmp_py = str(tmpdir.join("notebook.py"))
@@ -467,6 +467,7 @@ def test_set_kernel_auto(py_file, tmpdir):
     assert cmd == "python" or os.path.samefile(cmd, sys.executable)
 
 
+@requires_user_kernel_python3
 @pytest.mark.parametrize("py_file", list_notebooks("python"))
 def test_set_kernel_with_name(py_file, tmpdir):
     tmp_py = str(tmpdir.join("notebook.py"))
@@ -499,9 +500,9 @@ def test_paired_paths(nb_file, tmpdir, capsys):
     assert not err
 
     formats = nb.metadata.get("jupytext", {}).get("formats")
-    assert set(out.splitlines()).union([tmp_ipynb]) == set(
-        [path for path, _ in paired_paths(tmp_ipynb, "ipynb", formats)]
-    )
+    assert set(out.splitlines()).union([tmp_ipynb]) == {
+        path for path, _ in paired_paths(tmp_ipynb, "ipynb", formats)
+    }
 
 
 @pytest.mark.parametrize("nb_file", list_notebooks("ipynb_py"))
@@ -672,8 +673,9 @@ def test_cli_can_infer_jupytext_format_from_stdin(nb_file, tmpdir, cwd_tmpdir):
     compare_notebooks(nb2, nb, "Rmd")
 
 
+@requires_user_kernel_python3
 def test_set_kernel_works_with_pipes_326(capsys):
-    md = u"""```python
+    md = """```python
 1 + 1
 ```"""
 
@@ -686,9 +688,11 @@ def test_set_kernel_works_with_pipes_326(capsys):
     assert "kernelspec" in nb.metadata
 
 
+@requires_user_kernel_python3
 @skip_on_windows
+@pytest.mark.filterwarnings("ignore")
 def test_utf8_out_331(capsys, caplog):
-    py = u"from IPython.core.display import HTML; HTML(u'\xd7')"
+    py = "from IPython.core.display import HTML; HTML(u'\xd7')"
 
     with mock.patch("sys.stdin", StringIO(py)):
         jupytext(["--to", "ipynb", "--execute", "-"])
@@ -699,10 +703,11 @@ def test_utf8_out_331(capsys, caplog):
     nb = reads(out, "ipynb")
     assert len(nb.cells) == 1
     print(nb.cells[0].outputs)
-    assert nb.cells[0].outputs[0]["data"]["text/html"] == u"\xd7"
+    assert nb.cells[0].outputs[0]["data"]["text/html"] == "\xd7"
 
 
 @requires_jupytext_installed
+@pytest.mark.filterwarnings("ignore:The --pre-commit argument is deprecated")
 def test_cli_expect_errors(tmp_ipynb):
     with pytest.raises(ValueError):
         jupytext([])
@@ -722,6 +727,12 @@ def test_cli_expect_errors(tmp_ipynb):
         system("jupytext", ["notebook.ipynb", "--from", "py:percent", "--to", "md"])
 
 
+@pytest.mark.filterwarnings(
+    "error",
+    "ignore:You might have passed a file name to the '--to' option, "
+    "when a format description was expected. "
+    "Maybe you want to use the '-o' option instead?",
+)
 def test_format_prefix_suffix(tmpdir, cwd_tmpdir):
     os.makedirs("notebooks")
     tmp_ipynb = "notebooks/notebook_name.ipynb"
@@ -788,9 +799,43 @@ def test_cli_sync_file_with_suffix(tmpdir, cwd_tmpdir):
     jupytext(["--sync", tmp_lgt_py])
     jupytext(["--sync", tmp_ipynb])
 
-    assert open(tmp_lgt_py).read().splitlines()[-2:] == ["", "1+1"]
-    assert open(tmp_pct_py).read().splitlines()[-3:] == ["", "# %%", "1+1"]
-    assert open(tmp_rmd).read().splitlines()[-4:] == ["", "```{python}", "1+1", "```"]
+    with open(tmp_lgt_py) as fp:
+        assert fp.read().splitlines()[-2:] == ["", "1+1"]
+    with open(tmp_pct_py) as fp:
+        fp.read().splitlines()[-3:] == ["", "# %%", "1+1"]
+    with open(tmp_rmd) as fp:
+        fp.read().splitlines()[-4:] == ["", "```{python}", "1+1", "```"]
+
+
+def test_cli_sync_file_with_prefix_974(tmp_path, python_notebook):
+    """Only the files that are in the example directory and that start with 'example' should be paired"""
+    (tmp_path / "pyproject.toml").write_text(
+        """[tool.jupytext]
+formats = "examples//example/ipynb,examples//example/py:percent"
+"""
+    )
+
+    write(python_notebook, tmp_path / "example_notebook.ipynb")
+    (tmp_path / "examples" / "folder1").mkdir(parents=True)
+    write(python_notebook, tmp_path / "examples/folder1/utils.py")
+    write(python_notebook, tmp_path / "examples/folder1/example_paired.ipynb")
+
+    jupytext(
+        [
+            "--sync",
+            str(tmp_path / "example_notebook.ipynb"),
+            str(tmp_path / "examples/folder1/utils.py"),
+            str(tmp_path / "examples/folder1/example_paired.ipynb"),
+        ]
+    )
+
+    assert not (
+        tmp_path / "example_notebook.py"
+    ).exists(), "Not in the 'examples' directory"
+    assert not (
+        tmp_path / "examples/folder1/utils_not_paired.ipynb"
+    ).exists(), "Not with the 'example' prefix"
+    assert (tmp_path / "examples/folder1/example_paired.py").exists(), "Paired"
 
 
 @requires_sphinx_gallery
@@ -993,12 +1038,25 @@ def test_set_format_with_subfolder(tmpdir, cwd_tmpdir):
     )
 
 
-@requires_myst
-@requires_pandoc
+def skip_if_format_missing(format_name):
+    """Check whether MyST or Pandoc are available and skip if not"""
+    if format_name == "md:myst":
+        mark = requires_myst()
+    elif format_name == "md:pandoc":
+        mark = requires_pandoc()
+    else:
+        return
+
+    if mark.args[0]:
+        pytest.skip(**mark.kwargs)
+
+
 @pytest.mark.parametrize("format_name", ["md", "md:myst", "md:pandoc"])
 def test_create_header_with_set_formats(format_name, cwd_tmpdir, tmpdir):
     """Test jupytext --set-formats <format_name> #485"""
 
+    skip_if_format_missing(format_name)
+
     tmpdir.join("notebook.md").write("\n")
 
     jupytext(["--set-formats", format_name, "notebook.md"])
@@ -1007,14 +1065,15 @@ def test_create_header_with_set_formats(format_name, cwd_tmpdir, tmpdir):
     assert nb["metadata"]["jupytext"]["formats"] == format_name
 
 
-@requires_myst
-@requires_pandoc
+@requires_user_kernel_python3
 @pytest.mark.parametrize(
     "format_name", ["md", "md:myst", "md:pandoc", "py:light", "py:percent"]
 )
 def test_create_header_with_set_formats_and_set_kernel(format_name, tmpdir, cwd_tmpdir):
     """Test jupytext --set-formats <format_name> --set-kernel - #485"""
 
+    skip_if_format_missing(format_name)
+
     ext = format_name.split(":")[0]
     tmp_nb = "notebook." + ext
     tmpdir.join(tmp_nb).write("\n")
@@ -1132,28 +1191,6 @@ def test_sync_script_dotdot_folder_564(tmpdir):
     jupytext(["--sync", str(nb_file)])
 
 
-@contextmanager
-def no_warning():
-    with pytest.warns(None) as records:
-        yield
-
-    # There should be no warning
-    for record in records:
-        # Temporary exception for for this one, see #865
-        if (
-            "Passing a schema to Validator.iter_errors is deprecated "
-            "and will be removed in a future release" in str(record.message)
-        ):
-            continue
-        raise RuntimeError(record)
-
-
-def test_no_warning():
-    with pytest.raises(RuntimeError, match="a sample warning"):
-        with no_warning():
-            warnings.warn("a sample warning")
-
-
 def test_jupytext_to_file_emits_a_warning(tmpdir):
     """The user may type
         jupytext notebook.ipynb --to script.py
@@ -1165,7 +1202,8 @@ def test_jupytext_to_file_emits_a_warning(tmpdir):
     nb_file = tmpdir.join("notebook.ipynb")
     write(new_notebook(), str(nb_file))
 
-    with no_warning():
+    with warnings.catch_warnings():
+        warnings.simplefilter("error")
         jupytext(["notebook.ipynb", "-o", "script.py"])
 
     with pytest.warns(UserWarning, match="Maybe you want to use the '-o' option"):
@@ -1186,7 +1224,8 @@ def test_jupytext_set_formats_file_gives_an_informative_error(tmpdir, cwd_tmpdir
     nb_file = tmpdir.join("notebook.ipynb")
     md_file.write("Some text")
 
-    with no_warning():
+    with warnings.catch_warnings():
+        warnings.simplefilter("error")
         jupytext(["--sync", "notebook.md"])
 
     assert py_file.exists()
@@ -1410,3 +1449,39 @@ def test_round_trip_with_null_metadata_792(tmpdir, cwd_tmpdir, python_notebook):
     jupytext(["--to", "ipynb", "test.py"])
     nb = read("test.ipynb")
     assert nb.metadata.kernelspec.env is None
+
+
+def test_set_shebang_with_update_metadata(tmp_path, python_notebook):
+    tmp_py = tmp_path / "nb.py"
+    write(python_notebook, tmp_py, fmt="py:percent")
+
+    jupytext(
+        [
+            str(tmp_py),
+            "--update-metadata",
+            '{"jupytext":{"executable":"/usr/bin/python"}}',
+        ]
+    )
+
+    assert tmp_py.read_text().startswith("#!/usr/bin/python")
+
+
+@pytest.mark.parametrize("compare_ids", [False, True])
+@pytest.mark.parametrize("compare_outputs", [False, True])
+def test_set_formats_does_not_override_existing_ipynb(
+    tmp_path, notebook_with_outputs, compare_ids, compare_outputs
+):
+    tmp_py = tmp_path / "nb.py"
+    tmp_ipynb = tmp_path / "nb.ipynb"
+    write(notebook_with_outputs, tmp_ipynb)
+
+    jupytext([str(tmp_ipynb), "--set-formats", "ipynb,py:percent"])
+    jupytext([str(tmp_py), "--set-formats", "ipynb,py:percent"])
+
+    nb = read(tmp_ipynb)
+    compare_notebooks(
+        nb,
+        notebook_with_outputs,
+        compare_ids=compare_ids,
+        compare_outputs=compare_outputs,
+    )
