@@ -4,10 +4,14 @@ from pre_commit.main import main as pre_commit
 
 from jupytext import read, write
 
-from .utils import skip_pre_commit_tests_on_windows
+from .utils import (
+    skip_pre_commit_tests_on_windows,
+    skip_pre_commit_tests_when_jupytext_folder_is_not_a_git_repo,
+)
 
 
 @skip_pre_commit_tests_on_windows
+@skip_pre_commit_tests_when_jupytext_folder_is_not_a_git_repo
 def test_pre_commit_hook_sync_black_nbstripout(
     tmpdir,
     cwd_tmpdir,
@@ -25,15 +29,15 @@ repos:
   - id: jupytext
     args: [--sync, --pipe, black]
     additional_dependencies:
-    - black==20.8b1  # Matches hook
+    - black==22.3.0  # Matches hook
 
 - repo: https://github.com/psf/black
-  rev: 20.8b1
+  rev: 22.3.0
   hooks:
   - id: black
 
 - repo: https://github.com/kynan/nbstripout
-  rev: 0.3.9
+  rev: 0.5.0
   hooks:
   - id: nbstripout
 """
@@ -42,8 +46,8 @@ repos:
     tmp_repo.git.add(".pre-commit-config.yaml")
     pre_commit(["install", "--install-hooks", "-f"])
 
-    tmpdir.join(".jupytext.toml").write('formats = "ipynb,py:percent"')
-    tmp_repo.git.add(".jupytext.toml")
+    tmpdir.join("jupytext.toml").write('formats = "ipynb,py:percent"')
+    tmp_repo.git.add("jupytext.toml")
     tmp_repo.index.commit("pair notebooks")
 
     # write a test notebook
